@@ -5,8 +5,14 @@ from typing import Dict
 from typing import List
 
 from asgiref.sync import async_to_sync
-from channels.layers import get_channel_layer
+
+try:
+    from channels.layers import get_channel_layer
+except ModuleNotFoundError:
+    get_channel_layer = None
+
 from django.core.exceptions import ValidationError
+
 from django.db import models
 from django.db import transaction
 from django.utils.translation import gettext_lazy as _
@@ -31,24 +37,24 @@ class TrackableMixin:
         abstract = True
 
     def save(self, *args, **kw):
-        print(f"Saving {self}")
         result = super().save(*args, **kw)
-        channel_layer = get_channel_layer()
-        model_identifier = DELIMITER.join(
-            [self._meta.app_label, self._meta.model_name, str(self.pk)]
-        )
-        message = dict(
-            type="saved",
-            message=dict(
-                app=self._meta.app_label, model=self._meta.model_name, pk=self.pk
-            ),
-        )
-        print(f"Sending {message!r} to {model_identifier!r}")
+        if get_channel_layer:
+            channel_layer = get_channel_layer()
+            model_identifier = DELIMITER.join(
+                [self._meta.app_label, self._meta.model_name, str(self.pk)]
+            )
+            message = dict(
+                type="saved",
+                message=dict(
+                    app=self._meta.app_label, model=self._meta.model_name, pk=self.pk
+                ),
+            )
+            print(f"Sending {message!r} to {model_identifier!r}")
 
-        def on_commit() -> None:
-            async_to_sync(channel_layer.group_send)(model_identifier, message)
+            def on_commit() -> None:
+                async_to_sync(channel_layer.group_send)(model_identifier, message)
 
-        transaction.on_commit(on_commit)
+            transaction.on_commit(on_commit)
         return result
 
     def clean(self, *args, **kw):
